<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="诊室编号" prop="roomId">
        <el-select v-model="formData.roomId" placeholder="请输入诊室编号" >
          <el-option
            v-for="rooms in roomListRef"
            :key="rooms.roomId"
            :label="rooms.roomName"
            :value="rooms.roomId"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="诊疗床编号" prop="bedNo">
        <el-input v-model="formData.bedNo" placeholder="请输入诊疗床编号" />
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { RoomApi, RoomVO } from '@/api/ecg/room'

/** 诊室和诊疗床 表单 */
defineOptions({ name: 'RoomForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  roomId: undefined,
  roomName: undefined,
  bedNo: undefined
})
const formRules = reactive({
  roomId: [{ required: true, message: '诊室编号不能为空', trigger: 'blur' }],
  bedNo: [{ required: true, message: '诊疗床编号不能为空', trigger: 'blur' }]
})
const formRef = ref() // 表单 Ref
const roomListRef = ref<RoomVO[]>([]) // 列表的数据

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await RoomApi.getRoom(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as RoomVO
    data.roomName = getRoomNameById( data.roomId )
    if (formType.value === 'create') {
      await RoomApi.createRoom(data)
      message.success(t('common.createSuccess'))
    } else {
      await RoomApi.updateRoom(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    roomId: undefined,
    roomName: undefined,
    bedNo: undefined
  }
  formRef.value?.resetFields()
}

/** 查询诊室列表 */
const getSimpleRoomList = async () => {
      const data = await RoomApi.getSimpleRoomList()
      roomListRef.value = data
}

const getRoomNameById = (id) => {
    return roomListRef.value.find( e => e.roomId === id)!.roomName
}

/** 初始化 **/
onMounted(() => {
    getSimpleRoomList()
})

</script>
